@@ -16,6 +16,12 @@ from pygeoweaver.utils import (
 
 
 def detail_workflow(workflow_id):
+    """
+    Display detailed information about a workflow.
+
+    :param workflow_id: The ID of the workflow.
+    :type workflow_id: str
+    """
     if not workflow_id:
         raise RuntimeError("Workflow id is missing")
     download_geoweaver_jar()
@@ -30,8 +36,13 @@ def detail_workflow(workflow_id):
         cwd=f"{get_root_dir()}/",
     )
 
-
 def detail_process(process_id):
+    """
+    Display detailed information about a process.
+
+    :param process_id: The ID of the process.
+    :type process_id: str
+    """
     if not process_id:
         raise RuntimeError("Process id is missing")
     download_geoweaver_jar()
@@ -46,8 +57,13 @@ def detail_process(process_id):
         cwd=f"{get_root_dir()}/",
     )
 
-
 def detail_host(host_id):
+    """
+    Display detailed information about a host.
+
+    :param host_id: The ID of the host.
+    :type host_id: str
+    """
     if not host_id:
         raise RuntimeError("Host id is missing")
     download_geoweaver_jar()
@@ -62,8 +78,15 @@ def detail_host(host_id):
         cwd=f"{get_root_dir()}/",
     )
 
-
 def get_process_code(process_id):
+    """
+    Get the code of a process.
+
+    :param process_id: The ID of the process.
+    :type process_id: str
+    :return: The code of the process.
+    :rtype: str
+    """
     r = requests.post(
         f"{GEOWEAVER_DEFAULT_ENDPOINT_URL}/web/detail",
         data={"type": "process", "id": process_id},
